default.asp
Description: Louisiana Supreme Court is the state’s highest court located in the City of New Orleans.
Keywords: Louisiana Supreme Court, opinions, law, legal, lawyer, attorney, decision, opinion, judicial, official, appeals, rule, docket, calendar, decisions, state judiciary, clerk of court, law library, judicial administrator, bar examination, judicial campaign oversight, judicial college, judiciary commission, judicial council, district court, catalog, biography, judicial district, families in need of services, drug court, protective order registry, judicial compensation, news release

Home | Court Rules | News Releases | Docket | Clerk's Office
Search |  |
Advanced Search | Translate
About The Court
History Biographies of Justices Maps of Judicial Districts FAQ About the Court
Judicial Administrator's Office
Judicial Administrator Forms for Judges
Law Library & Legal Resources
Library Information Library Catalog Forms
Louisiana Judicial Entities
Judiciary Commission Judicial Council Judicial College Attorney Disciplinary Board Bar Admissions Committee Mandatory Continuing Legal Education
Press Room
Policy for Media Press Releases Bar Exam Results Publications
Community Outreach
Law Day Education Kid's Page
Employment
Job Opportunities Current Openings ADA Statement EEO Policy
Court Managed Programs
Children and Families Court Interpreters Drug Courts Louisiana Protective Order Registry (LPOR)
Court Administrators Association
LA Court Administrators Association
Additional Information
Judicial Campaign Oversight Committee Records Custodians Invitations to Comment Links: Other Courts and Associations Judicial Compensation Commission Site Map In Memoriam Contact Us
Translate
| Gadgets powered by Google
Disclaimer
Notice: For purposes of pinpoint citation, the pagination of the opinions on this site may not conform with the official opinion of the court.
2014 News Release Index
News Release | Date | Type
2014-037 | June 30, July 3, 7, 8, 9, and 11, 2014 | Actions
2014-036 | July 1, 2014 | Rehearings
2014-035 | July 1, 2014 | Opinions
2014-034 | June 20, 23, 27, and 30, 2014 | Actions
2014-033 | June 20, 2014 | Rehearing
2014-032 | June 17, 18, and 20, 2014 | Actions
2014-031 | June 6, 8, 11, and 13, 2014 | Actions
2014-030 | May 23, 27, and 30, 2014 | Actions
2014-029 | May 23, 2014 | Opinion
2014-028 | May 16, 17, 21 and 23, 2014 | Actions
2014-027 | May 7, 9, 12, 13, 14, 15, and 16, 2014 | Actions
2014-026 | May 7, 2014 | Opinions
2014-025 | May 2, 2014 | Rehearings
2014-024 | May 1 and 2, 2014 | Actions
2014-023 | April 25, 2014 | Rehearing
2014-022 | April 22 and 25, 2014 | Actions
2014-021 | April 15 and 17, 2014 | Actions
2014-020 | April 8, 9, and 11, 2014 | Actions
2014-019 | April 4, 2014 | Rehearings
2014-018 | April 2, 3, and 4, 2014 | Actions
2014-017 | March 21, 25, 26, and 28, 2014 | Actions
2014-016 | March 25, 2014 | Opinions
2014-015 | March 17, 19, 20, and 21, 2014 | Actions
2014-014 | March 7, 10, 12, and 14, 2014 | Actions
2014-013 | February 25, 26, and 28, 2014 | Actions
2014-012 | February 17, 19, and 21, 2014 | Actions
2014-011 | February 14, 2014 | Opinions
2014-010 | February 7, 10, 12, and 14, 2014 | Actions
2014-009 | February 6 and 7, 2014 | Actions
2014-008 | January 27, 2014 | Action
2014-007 | January 28, 2014 | Opinions
2014-006 | January 27, 2014 | Rehearings
2014-005 | January 17, 21, 23, and 27, 2014 | Actions
2014-004 | January 10, 15, and 17, 2014 | Actions
2014-003 | January 10, 2014 | Opinion
2014-002 | January 8 and 10, 2014 | Actions
2014-001 | January 3, 2014 | Action
| | HOME | COURT RULES | NEWS RELEASES | DOCKET | CLERK'S OFFICE | Louisiana Supreme Court, 400 Royal St., New Orleans, LA 70130 Clerk of Court's Office (504) 310-2300 Judicial Administrator's Office (504) 310-2550 Law Library of Louisiana (504) 310-2400 Email: webmaster@lasc.org Employee Access